import { render as vueRender } from 'vue';
import { createPlugin } from '@fullcalendar/core';
/*
wrap it in an object with a `vue` key, which the custom content-type handler system will look for
*/
export function wrapVDomGenerator(vDomGenerator) {
    return function (props) {
        return { vue: vDomGenerator(props) };
    };
}
export function createVueContentTypePlugin(appContext) {
    return createPlugin({
        contentTypeHandlers: {
            vue: () => buildVDomHandler(appContext), // looks for the `vue` key
        }
    });
}
function buildVDomHandler(appContext) {
    let currentEl;
    function render(el, vDomContent) {
        if (currentEl !== el) {
            if (currentEl) { // if changing elements, recreate the vue
                vueRender(null, currentEl);
            }
            currentEl = el;
        }
        const vnode = vDomContent[0];
        vnode.appContext = appContext;
        vueRender(vnode, el);
    }
    function destroy() {
        if (currentEl) {
            vueRender(null, currentEl);
        }
    }
    return { render, destroy };
}
//# sourceMappingURL=custom-content-type.js.map